@@ -1,11 +1,11 @@
 from typing import Dict
 
-MONGO_HOST_NAME_CONFIGURATION_KEY = "Mongo.Host"
-MONGO_DATABASE_NAME_CONFIGURATION_KEY = "Mongo.Database"
-MONGO_PORT_NAME_CONFIGURATION_KEY = "Mongo.Port"
-MONGO_USER_CONFIGURATION_KEY = "Mongo.User"
-MONGO_PASSWORD_CONFIGURATION_KEY = "Mongo.Password"
-MONGO_CUSTOM_CONNECTION_STRING_CONFIGURATION_KEY = "Mongo.CustomConnectionString"
+MONGO_HOST_NAME_CONFIGURATION_KEY = 'Mongo.Host'
+MONGO_DATABASE_NAME_CONFIGURATION_KEY = 'Mongo.Database'
+MONGO_PORT_NAME_CONFIGURATION_KEY = 'Mongo.Port'
+MONGO_USER_CONFIGURATION_KEY = 'Mongo.User'
+MONGO_PASSWORD_CONFIGURATION_KEY = 'Mongo.Password'
+MONGO_CUSTOM_CONNECTION_STRING_CONFIGURATION_KEY = 'Mongo.CustomConnectionString'
 
 
 class MongoConfiguration:
