@@ -5,34 +5,35 @@ from nislmigrate.extensibility.migrator_plugin import MigratorPlugin
 from nislmigrate.facades.file_system_facade import FileSystemFacade
 from nislmigrate.facades.mongo_configuration import MongoConfiguration
 from nislmigrate.facades.mongo_facade import MongoFacade
+from typing import Any, Dict
 
 
 class StatesMigrator(MigratorPlugin):
 
     @property
     def name(self):
-        return "SystemsStateManager"
+        return 'SystemsStateManager'
 
     @property
     def argument(self):
-        return "states"
+        return 'states'
 
     @property
     def help(self):
-        return "Migrate system states"
+        return 'Migrate system states'
 
     __data_directory = os.path.join(
-        str(os.environ.get("ProgramData")),
-        "National Instruments",
-        "Skyline",
-        "Data",
-        "SystemsStateManager")
+        str(os.environ.get('ProgramData')),
+        'National Instruments',
+        'Skyline',
+        'Data',
+        'SystemsStateManager')
 
-    def capture(self, migration_directory: str, facade_factory: FacadeFactory):
+    def capture(self, migration_directory: str, facade_factory: FacadeFactory, arguments: Dict[str, Any]):
         mongo_facade: MongoFacade = facade_factory.get_mongo_facade()
         file_facade: FileSystemFacade = facade_factory.get_file_system_facade()
         mongo_configuration: MongoConfiguration = MongoConfiguration(self.config(facade_factory))
-        file_migration_directory = os.path.join(migration_directory, "files")
+        file_migration_directory = os.path.join(migration_directory, 'files')
 
         mongo_facade.capture_database_to_directory(
             mongo_configuration,
@@ -43,11 +44,11 @@ class StatesMigrator(MigratorPlugin):
             file_migration_directory,
             False)
 
-    def restore(self, migration_directory: str, facade_factory: FacadeFactory):
+    def restore(self, migration_directory: str, facade_factory: FacadeFactory, arguments: Dict[str, Any]):
         mongo_facade: MongoFacade = facade_factory.get_mongo_facade()
         file_facade: FileSystemFacade = facade_factory.get_file_system_facade()
         mongo_configuration: MongoConfiguration = MongoConfiguration(self.config(facade_factory))
-        file_migration_directory = os.path.join(migration_directory, "files")
+        file_migration_directory = os.path.join(migration_directory, 'files')
 
         mongo_facade.restore_database_from_directory(
             mongo_configuration,
@@ -58,7 +59,11 @@ class StatesMigrator(MigratorPlugin):
             self.__data_directory,
             True)
 
-    def pre_restore_check(self, migration_directory: str, facade_factory: FacadeFactory) -> None:
+    def pre_restore_check(
+            self,
+            migration_directory: str,
+            facade_factory: FacadeFactory,
+            arguments: Dict[str, Any]) -> None:
         mongo_facade: MongoFacade = facade_factory.get_mongo_facade()
         mongo_facade.validate_can_restore_database_from_directory(
             migration_directory,
