@@ -3,6 +3,7 @@ from nislmigrate.facades.facade_factory import FacadeFactory
 from nislmigrate.facades.file_system_facade import FileSystemFacade
 from nislmigrate.facades.mongo_configuration import MongoConfiguration
 import os
+from typing import Any, Dict
 
 from nislmigrate.facades.mongo_facade import MongoFacade
 
@@ -11,24 +12,24 @@ class TagMigrator(MigratorPlugin):
 
     @property
     def name(self):
-        return "TagHistorian"
+        return 'TagHistorian'
 
     @property
     def argument(self):
-        return "tags"
+        return 'tags'
 
     @property
     def help(self):
-        return "migrate tags and tag histories"
+        return 'migrate tags and tag histories'
 
-    __file_to_migrate = "dump.rdb"
+    __file_to_migrate = 'dump.rdb'
     __file_to_migrate_directory = os.path.join(
-        str(os.environ.get("ProgramData")),
-        "National Instruments",
-        "Skyline",
-        "KeyValueDatabase")
+        str(os.environ.get('ProgramData')),
+        'National Instruments',
+        'Skyline',
+        'KeyValueDatabase')
 
-    def capture(self, migration_directory: str, facade_factory: FacadeFactory):
+    def capture(self, migration_directory: str, facade_factory: FacadeFactory, arguments: Dict[str, Any]):
         mongo_facade: MongoFacade = facade_factory.get_mongo_facade()
         file_facade: FileSystemFacade = facade_factory.get_file_system_facade()
         mongo_configuration: MongoConfiguration = MongoConfiguration(self.config(facade_factory))
@@ -41,7 +42,7 @@ class TagMigrator(MigratorPlugin):
             migration_directory,
             self.__file_to_migrate)
 
-    def restore(self, migration_directory: str, facade_factory: FacadeFactory):
+    def restore(self, migration_directory: str, facade_factory: FacadeFactory, arguments: Dict[str, Any]):
         mongo_facade: MongoFacade = facade_factory.get_mongo_facade()
         file_facade: FileSystemFacade = facade_factory.get_file_system_facade()
         mongo_configuration: MongoConfiguration = MongoConfiguration(self.config(facade_factory))
@@ -54,7 +55,11 @@ class TagMigrator(MigratorPlugin):
             self.__file_to_migrate_directory,
             self.__file_to_migrate)
 
-    def pre_restore_check(self, migration_directory: str, facade_factory: FacadeFactory) -> None:
+    def pre_restore_check(
+            self,
+            migration_directory: str,
+            facade_factory: FacadeFactory,
+            arguments: Dict[str, Any]) -> None:
         mongo_facade: MongoFacade = facade_factory.get_mongo_facade()
         mongo_facade.validate_can_restore_database_from_directory(
             migration_directory,
